@@ -43,11 +43,12 @@ def console_entry_point():
     parser = sub_parser.add_parser('install', description="Install other packages with yay, have to be logged with an user or provide one.", formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('--pre-config', action='store_true', help='''
 Install and configure packages if exist.
-    *** gnome, imwheel, teamviewer, virtualbox, docker
+    *** gnome, imwheel, teamviewer, virtualbox, docker, intellij
 There is some groups of packages:
     util-packages = (nano zip unzip wget bash-completion openssh seahorse networkmanager-fortisslvpn)
     dev-packages = (maven npm vagrant packer git python python-pip docker virtualbox)
-    tools-packages = (google-chrome variety slack-desktop intellij-idea-ultimate-edition teamviewer)
+    tools-packages = (google-chrome variety slack-desktop intellij teamviewer)
+    all-packages = (util-packages dev-packages tools-packages imwheel gnome)
     ''')
     parser.add_argument('--user', help='User that install packages; used only if you are logged as root.')
     parser.add_argument('package', nargs='*')
