@@ -284,7 +284,9 @@ function alis_install_package() {
     exit 1
   fi
 
-  install_official_packages git
+  if ! pacman -Q | grep git -q; then
+    install_official_packages git
+  fi
 
   if [[ "$PRE_CONFIG" == True ]]; then
     local ALL_PACKAGES
@@ -303,11 +305,11 @@ function alis_install_package() {
           ;;
         gnome)
           ALL_PACKAGES+=(gnome gnome-extra matcha-gtk-theme xcursor-breeze papirus-maia-icon-theme-git ttf-dejavu noto-fonts ttf-liberation gnome-shell-extensions gnome-shell-extension-topicons-plus chrome-gnome-shell evolution-ews evolution-on)
-          ALL_CONFIG+=(gnome_terminal_transparency_user gnome_system gnome_user)
+          ALL_CONFIG+=(gnome_terminal_transparency_user gnome_system)
           ;;
         docker)
           ALL_PACKAGES+=(docker docker-compose)
-          ALL_CONFIG+=("docker_system $RUNNING_USER" docker_user)
+          ALL_CONFIG+=("docker_system $RUNNING_USER")
           ;;
         virtualbox)
           ALL_PACKAGES+=(virtualbox virtualbox-host-modules-arch virtualbox-guest-iso)
@@ -321,6 +323,10 @@ function alis_install_package() {
           ALL_PACKAGES+=(imwheel)
           ALL_CONFIG+=(imwheel_user)
           ;;
+        intellij)
+          ALL_PACKAGES+=(intellij-idea-ultimate-edition jdk11-openjdk)
+          ALL_CONFIG+=(intellij_system)
+          ;;
         util-packages)
           collect_configs nano zip unzip wget bash-completion openssh seahorse networkmanager-fortisslvpn
           ;;
@@ -328,7 +334,10 @@ function alis_install_package() {
           collect_configs maven npm vagrant packer git python python-pip docker virtualbox
           ;;
         tools-packages)
-          collect_configs google-chrome variety slack-desktop intellij-idea-ultimate-edition teamviewer
+          collect_configs google-chrome variety slack-desktop intellij teamviewer
+          ;;
+        all-packages)
+          collect_configs util-packages dev-packages tools-packages imwheel gnome
           ;;
         *)
           ALL_PACKAGES+=( "$PKG" )
@@ -441,7 +450,7 @@ icon-brightness=2.7755575615628914e-17
 icon-contrast=2.7755575615628914e-17
 icon-opacity=230
 icon-saturation=0.40000000000000002
-icon-size=15
+icon-size=16
 tray-order=2
 tray-pos='right'
 
@@ -551,63 +560,6 @@ EOT
     if systemctl is-active --quiet dbus; then
       dconf update
     fi
-
-    locale-gen
-  }
-
-  function gnome_user() {
-    mkdir -p ~/.config/autostart
-    cat <<'EOT' >~/.config/autostart/org.gnome.Evolution.desktop
-[Desktop Entry]
-Name=Evolution
-GenericName=Groupware Suite
-X-GNOME-FullName=Evolution Mail and Calendar
-Comment=Manage your email, contacts and schedule
-Keywords=email;calendar;contact;addressbook;task;
-Actions=new-window;compose;contacts;calendar;mail;memos;tasks;
-Exec=evolution %U
-Icon=evolution
-Terminal=false
-Type=Application
-Categories=GNOME;GTK;Office;Email;Calendar;ContactManagement;X-Red-Hat-Base;
-StartupNotify=true
-X-GNOME-Bugzilla-Bugzilla=GNOME
-X-GNOME-Bugzilla-Product=Evolution
-X-GNOME-Bugzilla-Component=BugBuddyBugs
-X-GNOME-Bugzilla-Version=3.38.x
-X-GNOME-Bugzilla-OtherBinaries=evolution-addressbook-factory;evolution-calendar-factory;evolution-source-registry;evolution-user-prompter;
-X-GNOME-UsesNotifications=true
-X-Flatpak-RenamedFrom=evolution
-MimeType=text/calendar;text/x-vcard;text/directory;application/mbox;message/rfc822;x-scheme-handler/mailto;x-scheme-handler/webcal;x-scheme-handler/calendar;x-scheme-handler/task;x-scheme-handler/memo;
-
-[Desktop Action new-window]
-Name=New Window
-Exec=evolution -c current
-
-[Desktop Action compose]
-Name=Compose a Message
-Exec=evolution mailto:
-
-[Desktop Action contacts]
-Name=Contacts
-Exec=evolution -c contacts
-
-[Desktop Action calendar]
-Name=Calendar
-Exec=evolution -c calendar
-
-[Desktop Action mail]
-Name=Mail
-Exec=evolution -c mail
-
-[Desktop Action memos]
-Name=Memos
-Exec=evolution -c memos
-
-[Desktop Action tasks]
-Name=Tasks
-Exec=evolution -c tasks
-EOT
   }
 
   function gnome_terminal_transparency_user() {
@@ -621,12 +573,6 @@ EOT
     usermod -aG docker "$1"
   }
 
-  function docker_user() {
-    if systemctl is-active --quiet docker; then
-      newgrp docker
-    fi
-  }
-
   function virtualbox_system() {
     vboxreload
   }
@@ -665,6 +611,12 @@ X-DBUS-StartupType=
 X-KDE-SubstituteUID=false
 X-KDE-Username=
 EOT
+
+    /usr/bin/imwheel -b 45 &
+  }
+  
+  function intellij_system() {
+    archlinux-java set java-11-openjdk
   }
 
   ARGUMENTS=$(printf '%q ' "${*:2}")
